@@ -82,6 +82,9 @@ class TupleDataObservableHandler:
     def hasTupleProvider(self, tupleName: str):
         return tupleName in self._tupleProvidersByTupleName
 
+    def hasTupleSubscribers(self, tupleSelector:TupleSelector):
+        return tupleSelector.toJsonStr() in self._observerDetailsByTupleSelector
+
     def shutdown(self):
         self._endpoint.shutdown()
 
@@ -141,6 +144,19 @@ class TupleDataObservableHandler:
         """
         reactor.callLater(0, self._notifyOfTupleUpdateInMain, tupleSelector)
 
+    def notifyOfTupleUpdateForTuple(self, tupleName: str) -> None:
+        """ Notify of Tuple Update for Tuple
+
+        Like the above notification method, this method will aquire new data and
+        send it to observers.
+
+        """
+        for tupleSelectorStr in self._observerDetailsByTupleSelector:
+            tupleSelector = TupleSelector.fromJsonStr(tupleSelectorStr)
+
+            if tupleSelector.name == tupleName:
+                self.notifyOfTupleUpdate(tupleSelector)
+
     @inlineCallbacks
     def _notifyOfTupleUpdateInMain(self, tupleSelector: TupleSelector):
         tsStr = tupleSelector.toJsonStr()
@@ -162,10 +178,14 @@ class TupleDataObservableHandler:
         filt.update(self._filt)
         vortexMsg = yield self._createVortexMsg(filt, tupleSelector)
 
+        # We can have multiple Observable clients on the one vortex, so make sure
+        # we only send one message for these.
+        destVortexUuids = set([od.vortexUuid for od in observerDetails])
+
         # Send the vortex messages
-        for od in observerDetails:
+        for destVortexUuid in destVortexUuids:
             d = VortexFactory.sendVortexMsg(vortexMsgs=vortexMsg,
-                                            destVortexUuid=od.vortexUuid)
+                                            destVortexUuid=destVortexUuid)
             d.addErrback(vortexLogFailure, logger)
 
     def _customMaybeDeferred(self, f, *args, **kw):
